@@ -16,11 +16,11 @@ Test::Unit::Debug - framework debugging control
 =cut
 
 use strict;
+use warnings;
 
 use base 'Exporter';
-use vars qw(@EXPORT_OK);
-@EXPORT_OK = qw(debug debug_to_file
-                debug_pkg no_debug_pkg debug_pkgs no_debug_pkgs debugged);
+our @EXPORT_OK = qw(debug debug_to_file
+                    debug_pkg no_debug_pkg debug_pkgs no_debug_pkgs debugged);
 
 my %DEBUG = ();
 my $out = \*STDERR;
@@ -99,6 +99,16 @@ sub debugged {
     return $DEBUG{$_[0] || $package};
 }
 
+
+=head1 AUTHOR
+
+Copyright (c) 2000-2002, 2005 the PerlUnit Development Team
+(see L<Test::Unit> or the F<AUTHORS> file included in this
+distribution).
+
+All rights reserved. This program is free software; you can
+redistribute it and/or modify it under the same terms as Perl itself.
+
 =head1 SEE ALSO
 
 L<Test::Unit>
