@@ -1,6 +1,7 @@
 package Test::Unit::Exception;
 
 use strict;
+use warnings;
 
 use Carp;
 use Error;
@@ -65,7 +66,7 @@ Test::Unit::Exception - unit testing framework exception class
 
 =head1 SYNOPSIS
 
-This class is not intended to be used directly 
+This class is not intended to be used directly
 
 =head1 DESCRIPTION
 
@@ -75,17 +76,12 @@ in case of errors or failures.
 
 =head1 AUTHOR
 
-Copyright (c) 2000 Christian Lemburg, E<lt>lemburg@acm.orgE<gt>.
+Copyright (c) 2000-2002, 2005 the PerlUnit Development Team
+(see L<Test::Unit> or the F<AUTHORS> file included in this
+distribution).
 
 All rights reserved. This program is free software; you can
-redistribute it and/or modify it under the same terms as
-Perl itself.
-
-Thanks go to the other PerlUnit framework people: 
-Brian Ewins, Cayte Lindner, J.E. Fritz, Zhon Johansen.
-
-Thanks for patches go to:
-Matthew Astley.
+redistribute it and/or modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
